import numpy as np

from chembench.metrics import (
    exact_str_match,
    mae,
    mse,
    all_correct,
    classification_scores,
)


def test_mae():
    assert mae("40", 40) == 0
    assert mae("41", 40) == 1
    assert mae("39", 40) == 1

    assert mae(40, 40) == 0
    assert np.isnan(mae(None, 40))


def test_mse():
    assert mse("40", 40) == 0
    assert mse("41", 40) == 1
    assert mse("39", 40) == 1

    assert mse(40, 40) == 0
    assert np.isnan(mse(None, 40))


def test_exact_str_match():
    assert exact_str_match("aa", "aa")
    assert not exact_str_match("aaa", "aa")


def test_all_correct():
    assert all_correct("aa", "aa")
    assert not all_correct("aa", "ab")
    assert all_correct("aa", {"aa": 1})
    assert not all_correct("aa", {"ab": 1})
    assert not all_correct("aa", {"aa": 0})
    assert all_correct("aa", {"aa": 1, "ab": 0})
    assert not all_correct("aa", {"aa": 0, "ab": 1})


def test_classification_scores():
    scores = classification_scores({"aa": 1, "ab": 0}, "aa")
    assert scores["precision"] == 1
    assert scores["recall"] == 1
    assert scores["f1"] == 1
